@@ -5,15 +5,14 @@ Information parsed from the API Gateway event.
 
 """
 
-import json
 from typing import Optional
 
+import simplejson as json
+
 
 class Request:
     """
-    Parsed Request object.
-
-    Request objects are created in @route handlers, are and accessible
+    Request objects created in @route handlers, and accessible
     from within the handler as the "request" argument.
     It contains parsed information about the API Gateway event.
 
@@ -30,7 +29,7 @@ class Request:
         self.event = event
 
     @property
-    def body(self):
+    def body(self) -> Optional[str]:
         """
         Return the raw body field of the API Gateway event.
 
@@ -40,7 +39,7 @@ class Request:
         >>> Request(event).body
         '{"name": "John Doe"}'
         """
-        return self._get_event_key("body", none_as_empty=False)
+        return self.event.get("body")
 
     @property
     def json(self) -> Optional[dict]:
@@ -59,7 +58,7 @@ class Request:
         return None
 
     @property
-    def path_params(self) -> Optional[dict]:
+    def path_params(self) -> dict:
         """
         Return the pathParameters field of the API Gateway event.
 
@@ -69,20 +68,21 @@ class Request:
         >>> Request(event).path_params
         {'user_id': 123}
         """
-        return self._get_event_key("pathParameters")
+
+        return self._get_event_key_none_as_empty("pathParameters")
 
     @property
-    def query_params(self) -> Optional[dict]:
+    def query_params(self) -> dict:
         """
         Return the queryStringParameters field of the API Gateway event.
 
         Examples
         --------
-        >>> event = {"queryStringParameters": {"page": 3}}
+        >>> event = {"queryStringParameters": {"page": "3"}}
         >>> Request(event).query_params
-        {'page': 3}
+        {'page': '3'}
         """
-        return self._get_event_key("queryStringParameters")
+        return self._get_event_key_none_as_empty("queryStringParameters")
 
     @property
     def method(self) -> str:
@@ -110,14 +110,12 @@ class Request:
         """
         return self.event["headers"]
 
-    def _get_event_key(
-        self, key: str, none_as_empty: bool = True
-    ) -> Optional[dict]:
+    def _get_event_key_none_as_empty(self, key: str) -> dict:
         """
         Get specific key from event object.
         """
         value = self.event.get(key)
-        if value is None and none_as_empty:
+        if value is None:
             return {}
 
         return value
